@@ -1,5 +1,7 @@
 __author__ = "sandyzikun"
-__version__ = "0.0.6"
+__version__ = "0.0.7"
 from . import datasets, fourier
 from . import hmm
+from . import ae
+from . import heartland
 print("あなたもミクと創ろう、世界を繋ごう。")
\ No newline at end of file
